@@ -19,7 +19,7 @@ class Curl(object):
 	def download_img(self, url, img):
 		url = self.base_url+url.replace('//','/')
 		os.system('curl -s -o {url} "{img}"')
-		if os.path.exists(img_path): return True
+		if Files.exists(img_path): return True
 		else: return False
 	def get(self, url, data=None):
 		url = self.base_url+url.replace('//','/')
